==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/players/xine/xineplayerconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "xineplayerconfigwidget.h"
#include "xineplayerconfigdefs.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>

#include <klocale.h>
#include <kcombobox.h>

using namespace SubtitleComposer;

XinePlayerConfigWidget::XinePlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QGroupBox* audioGroupBox = createGroupBox( i18n( "Audio" ) );

	m_audioDriverCheckBox = new QCheckBox( audioGroupBox );
	m_audioDriverCheckBox->setText( i18n( "Audio driver" ) );

	m_audioDriverComboBox = new KComboBox( false, audioGroupBox );
	m_audioDriverComboBox->setEnabled( false );
	m_audioDriverComboBox->setEditable( true );
	m_audioDriverComboBox->insertStringList( QStringList::split( ' ', "auto alsa oss jack pulseaudio esd" ) );


	QGroupBox* videoGroupBox = createGroupBox( i18n( "Video" ) );

	m_videoDriverCheckBox = new QCheckBox( videoGroupBox );
	m_videoDriverCheckBox->setText( i18n( "Video driver" ) );

	m_videoDriverComboBox = new KComboBox( false, videoGroupBox );
	m_videoDriverComboBox->setEnabled( false );
	m_videoDriverComboBox->setEditable( true );
	m_videoDriverComboBox->insertStringList( QStringList::split( ' ', "auto xv xvmc opengl xxmc sdl xshm fb XDirectFB DirectFB aa caca" ) );


	QGridLayout* audioLayout = createGridLayout( audioGroupBox );
	audioLayout->addWidget( m_audioDriverCheckBox, 0, 0 );
	audioLayout->addWidget( m_audioDriverComboBox, 0, 1 );

	QGridLayout* videoLayout = createGridLayout( videoGroupBox );
	videoLayout->addWidget( m_videoDriverCheckBox, 0, 0 );
	videoLayout->addWidget( m_videoDriverComboBox, 0, 1 );

	connect( m_audioDriverCheckBox, SIGNAL( toggled(bool) ), m_audioDriverComboBox, SLOT( setEnabled(bool) ) );
	connect( m_videoDriverCheckBox, SIGNAL( toggled(bool) ), m_videoDriverComboBox, SLOT( setEnabled(bool) ) );
	connect( m_audioDriverCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoDriverCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioDriverComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoDriverComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );

	setControlsFromConfig();
}

XinePlayerConfigWidget::~XinePlayerConfigWidget()
{
}

void XinePlayerConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption(
		OPT_AUDIO_DRIVER,
		m_audioDriverCheckBox->isChecked() ?
			m_audioDriverComboBox->currentText() :
			QString::null
	);

	m_configGroup.setOption(
		OPT_VIDEO_DRIVER,
		m_videoDriverCheckBox->isChecked() ?
			m_videoDriverComboBox->currentText() :
			QString::null
	);
}

void XinePlayerConfigWidget::setControlsFromConfig()
{
	QString value = m_configGroup.option( OPT_AUDIO_DRIVER );
	m_audioDriverCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_audioDriverComboBox->setEditText( value );

	value = m_configGroup.option( OPT_VIDEO_DRIVER );
	m_videoDriverCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_videoDriverComboBox->setEditText( value );
}

#include "xineplayerconfigwidget.moc"

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/players/xine/xineplayerconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "xineplayerconfigwidget.h"
#include "xineplayerconfigdefs.h"

#include <qlayout.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>

#include <klocale.h>
#include <kcombobox.h>

using namespace SubtitleComposer;

XinePlayerConfigWidget::XinePlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QButtonGroup* audioButtonGroup = createButtonGroup( i18n( "Audio" ) );

	m_audioDriverCheckBox = new QCheckBox( audioButtonGroup );
	m_audioDriverCheckBox->setText( i18n( "Audio driver" ) );

	m_audioDriverComboBox = new KComboBox( false, audioButtonGroup );
	m_audioDriverComboBox->setEnabled( false );
	m_audioDriverComboBox->setEditable( true );
	m_audioDriverComboBox->insertStringList( QStringList::split( ' ', "auto alsa oss jack pulseaudio esd" ) );


	QButtonGroup* videoButtonGroup = createButtonGroup( i18n( "Video" ) );

	m_videoDriverCheckBox = new QCheckBox( videoButtonGroup );
	m_videoDriverCheckBox->setText( i18n( "Video driver" ) );

	m_videoDriverComboBox = new KComboBox( false, videoButtonGroup );
	m_videoDriverComboBox->setEnabled( false );
	m_videoDriverComboBox->setEditable( true );
	m_videoDriverComboBox->insertStringList( QStringList::split( ' ', "auto xv xvmc opengl xxmc sdl xshm fb XDirectFB DirectFB aa caca" ) );


	QGridLayout* audioLayout = createGridLayout( audioButtonGroup );
	audioLayout->addWidget( m_audioDriverCheckBox, 0, 0 );
	audioLayout->addWidget( m_audioDriverComboBox, 0, 1 );

	QGridLayout* videoLayout = createGridLayout( videoButtonGroup );
	videoLayout->addWidget( m_videoDriverCheckBox, 0, 0 );
	videoLayout->addWidget( m_videoDriverComboBox, 0, 1 );


	connect( m_audioDriverCheckBox, SIGNAL( toggled(bool) ), m_audioDriverComboBox, SLOT( setEnabled(bool) ) );
	connect( m_videoDriverCheckBox, SIGNAL( toggled(bool) ), m_videoDriverComboBox, SLOT( setEnabled(bool) ) );
	connect( m_audioDriverCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoDriverCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioDriverComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoDriverComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );

	setControlsFromConfig();
}

XinePlayerConfigWidget::~XinePlayerConfigWidget()
{
}

void XinePlayerConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption(
		OPT_AUDIO_DRIVER,
		m_audioDriverCheckBox->isChecked() ?
			m_audioDriverComboBox->currentText() :
			QString::null
	);

	m_configGroup.setOption(
		OPT_VIDEO_DRIVER,
		m_videoDriverCheckBox->isChecked() ?
			m_videoDriverComboBox->currentText() :
			QString::null
	);
}

void XinePlayerConfigWidget::setControlsFromConfig()
{
	QString value = m_configGroup.option( OPT_AUDIO_DRIVER );
	m_audioDriverCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_audioDriverComboBox->setEditText( value );

	value = m_configGroup.option( OPT_VIDEO_DRIVER );
	m_videoDriverCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_videoDriverComboBox->setEditText( value );
}

#include "xineplayerconfigwidget.moc"
